SystemOrganization addCategory: #ExcludedWeb1!

ReadWriteStream subclass: #SwazooBuffer1
	instanceVariableNames: 'type resize __ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!SwazooBuffer1 commentStamp: 'janko 7/26/2008 18:23' prior: 0!
SwazooBuffer is used for efficient buffering of receiving or sending data to TCP socket. Efficiency is achieved with reusing of stream content array instead of initializing it everytime buffer is emptied, as was in previous Swazoo versions. 

SwazooBuffer is a subclass of ReadWriteStream, with additional #clear to empty buffer.

!

!SwazooBuffer1 class methodsFor: 'defaults' stamp: 'janko 7/26/2008 18:25'!
defaultBufferSize
	"length of buffer at creation. Later not nessesary exactly this number!! "
	^8000 "about 8KB-preamble"
! !

!SwazooBuffer1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!SwazooBuffer1 class methodsFor: 'defaults' stamp: 'janko 8/3/2008 19:55'!
largeBufferSize
	"size of buffer for large uploads/downloads"
	^1000000	"about 1MB"! !

!SwazooBuffer1 class methodsFor: 'instance creation' stamp: 'jm 2/8/2009 14:47'!
newRead
	^(super on: Array new) setRead; initDefaultBuffer! !

!SwazooBuffer1 class methodsFor: 'instance creation' stamp: 'jm 2/8/2009 14:46'!
newWrite
	^(super on: Array new) setWrite;  initDefaultBuffer! !

!SwazooBuffer1 class methodsFor: 'instance creation' stamp: 'janko 7/26/2008 18:24'!
on: aByteStringOrArray
	^(self with: aByteStringOrArray) position: 0! !

!SwazooBuffer1 class methodsFor: 'defaults' stamp: ' 14/8/07 21:49'!
preambleSize
	"chunk size line (fixed to 4 hex characters) + crlf"
	^6! !

!SwazooBuffer1 methodsFor: 'testing' stamp: 'janko 7/26/2008 18:22'!
atEnd
	^super atEnd "for now"! !

!SwazooBuffer1 methodsFor: 'writing-chunked' stamp: ' 14/8/07 21:49'!
closeChunkTo: aSocket
	"a zero sized chunk determine and end of chunked data and also response"
	"pack all together to send one TCP packet ony"
	| chunk written |
	chunk := ByteString new: 5.
	chunk at: 1 put: $0 .
	chunk at: 2 put: Character cr. "first crlf ends 0 length line "
	chunk at: 3 put: Character lf.
	chunk at: 4 put: Character cr. "second crlf ends whole response"
	chunk at: 5 put: Character lf.
	written := aSocket writeFrom: chunk asByteArray startingAt: 1 for: chunk size.
	written = chunk size ifFalse: [self error: 'socket write error'].! !

!SwazooBuffer1 methodsFor: 'accessing' stamp: 'janko 7/26/2008 18:21'!
contents
	"Answer a copy of the receiver's collection, skipping preamble."
	readLimit := readLimit max: position.
	^collection copyFrom: self class preambleSize+1 to: readLimit! !

!SwazooBuffer1 methodsFor: 'mime boundary' stamp: 'janko 7/26/2008 18:16'!
copyBufferTo: anIndex
	"from current position to desired index"
	| start |
	start := position+1.
	position := anIndex.
	^collection copyFrom: start to: anIndex.! !

!SwazooBuffer1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/12/2012 14:18'!
ctxReadresize self isCtxGlobal
				 ifTrue: [ self synchronizeIfNecessary: 6 ]. ^  resize! !

!SwazooBuffer1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/12/2012 14:18'!
ctxReadtype self isCtxGlobal
				 ifTrue: [ self synchronizeIfNecessary: 5 ]. ^  type! !

!SwazooBuffer1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/12/2012 14:18'!
ctxWriteresize: v2 self isCtxGlobal
				 ifTrue: [ self synchronizeIfNecessary: 6 . self markOtherAsDirty: 6 ]. ^ resize := v2 secure  ! !

!SwazooBuffer1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/12/2012 14:18'!
ctxWritetype: v2 self isCtxGlobal
				 ifTrue: [ self synchronizeIfNecessary: 5 . self markOtherAsDirty: 5 ]. ^ type := v2 secure  ! !

!SwazooBuffer1 methodsFor: 'writing-chunked' stamp: 'mivsek 8/22/2007 20:22'!
flushChunkTo: aSocket
	"a buffer will be sent as a chunk, with hex size in first line then crlf, buffer, then crlf"
	"send a complete chunk in one piece, don't partition TCP sending in too many packets!!"
	| length |
	 self size > 16rFFFF ifTrue: [self error: 'chunk too long!!']. "preamble has no room for bigger"
	length := self size printStringRadix: 16.
	SpEnvironment isSqueak ifTrue: [length := length copyFrom: 4 to: length size]. "trim 16r"
	1 to: length size do: [:inx | collection at: inx put: (length at: inx) asInteger].
	 (length size+1) to: 4 do: [:inx | collection at: inx put: $ asInteger]. "add spaces"
	collection at: 5 put: Character cr asInteger.
	collection at: 6 put: Character lf asInteger.
	"add finishing crlf to buffer"
	self nextPut: Character cr asInteger.
	self nextPut: Character lf asInteger.
	self flushTo: aSocket chunked: true. "flush all at once"! !

!SwazooBuffer1 methodsFor: 'writing' stamp: ' 14/8/07 21:49'!
flushTo: aSocket
	"actually write to the tcp socket as direclty as possible"
	self flushTo: aSocket chunked: false.
! !

!SwazooBuffer1 methodsFor: 'private-sending' stamp: 'janko 8/3/2008 17:00'!
flushTo: aSocket chunked: chunkedBoolean
	"actually write to the tcp socket as direclty as possible 
	(directly from stream's instvar collection)"
	| remaining start written |
	remaining := chunkedBoolean 
		ifTrue: [position]  "ensure to send preamble too"
		ifFalse: [position - self class preambleSize]. "skip preamble"
	[remaining > 0] whileTrue: 
		[start := position - remaining + 1.
		written := aSocket 
			writeFrom: collection startingAt: start for: (position - start + 1).
		remaining := remaining - written].
	self writeClear.
	self shouldResize ifTrue: [self resizeBuffer; resizeNil]. "enlarge or shrink buffer if requested"! !

!SwazooBuffer1 methodsFor: 'mime boundary' stamp: 'janko 7/26/2008 18:17'!
indexOfBoundary: aBoundaryBytes
	"index of boundary start, beeing full boundary or part at the end of buffer. 0 if not found"
	| inx innerInx firstInx |
	inx := position+1.
	[inx <= readLimit] whileTrue:
		[innerInx := 1. firstInx := inx.
		[(aBoundaryBytes at: innerInx) = (collection at: inx)] whileTrue:
			[innerInx = aBoundaryBytes size ifTrue: [^firstInx]. "full boundary found"
			inx = readLimit ifTrue: [^firstInx].  "partial boundary at the edge of buffer found"
			inx := inx + 1. innerInx := innerInx + 1].
		inx := inx + 1].
	^0! !

!SwazooBuffer1 methodsFor: 'initialize-release' stamp: 'ewe 11/13/2012 12:05'!
initDefaultBuffer
	"Squeak specific - writeLimit"
	| size |
	size := self isWrite
		ifTrue: [self class defaultBufferSize + self class preambleSize + 2] "possible chunk crlf"
		ifFalse: [self class defaultBufferSize].
	collection := ByteArray new: size.
	writeLimit := size. "Squeak specific"
	self reset.
	self isWrite ifTrue: [self initPreamble].! !

!SwazooBuffer1 methodsFor: 'initialize-release' stamp: 'jm 2/8/2009 23:33'!
initLargeBuffer
	"Squeak specific - writeLimit"
	| size |
	size := self isWrite
		ifTrue: [self class largeBufferSize + self class preambleSize + 2] "possible chunk crlf"
		ifFalse: [self class largeBufferSize].
	collection := ByteArray new: size.
	writeLimit := size. "Squeak specific"
	self reset.
	self isWrite ifTrue: [self initPreamble].! !

!SwazooBuffer1 methodsFor: 'initialize-release' stamp: ' 14/8/07 21:49'!
initPreamble
	"make room for possible chunk 'preamble' = length line"
	position := self class preambleSize.
! !

!SwazooBuffer1 methodsFor: 'testing' stamp: 'janko 7/26/2008 18:22'!
isBinary
	^collection class == ByteArray! !

!SwazooBuffer1 methodsFor: 'private-resizing' stamp: 'janko 8/3/2008 16:58'!
isEnlarged
	^collection size > self class defaultBufferSize! !

!SwazooBuffer1 methodsFor: 'testing' stamp: 'janko 7/26/2008 18:21'!
isFull
	"buffer full or even more"
	^position >= self class defaultBufferSize! !

!SwazooBuffer1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!SwazooBuffer1 methodsFor: 'testing' stamp: 'janko 8/3/2008 16:57'!
isRead
	^type = #read! !

!SwazooBuffer1 methodsFor: 'testing' stamp: 'janko 8/3/2008 16:57'!
isWrite
	^type = #write! !

!SwazooBuffer1 methodsFor: 'initialize-release' stamp: 'janko 7/26/2008 18:14'!
readClear
	"reset as you'd make another one, just don't replace content array"
	position := 0.
	readLimit := self class defaultBufferSize.! !

!SwazooBuffer1 methodsFor: 'accessing' stamp: 'janko 7/26/2008 18:16'!
readContents
	^(position = 0 and: [readLimit = self class defaultBufferSize]) "whole buffer?"
		ifTrue: [collection] "avoid copying for performance"
		ifFalse: [collection copyFrom: position+1 to: readLimit]! !

!SwazooBuffer1 methodsFor: 'reading' stamp: 'janko 8/3/2008 17:01'!
refillFrom: aSocket
	"reset and read from to the tcp socket as direclty as possible 
	(directly from stream's instvar collection)"
	aSocket isNil ifTrue: [^self]. "if SwazooStream is used for tests only"
	self readClear. "just reset pointers, not a collection!! "
	self shouldResize ifTrue: [self resizeBuffer; resizeNil]. "enlarge or shrink buffer if requested"
	readLimit "nr. of actuall bytes read ":= aSocket
		readInto: collection startingAt: 1 for: collection size.
	self atEnd ifTrue: 
		[SwazooStreamNoDataError raiseSignal: 'No data available.  Socket probably closed']! !

!SwazooBuffer1 methodsFor: 'private-resizing' stamp: 'janko 8/3/2008 16:59'!
resizeBuffer
	"actually do a buffer resize"
	self shouldEnlarge ifTrue: [^self initLargeBuffer].
	self shouldShrink ifTrue: [^self initDefaultBuffer].! !

!SwazooBuffer1 methodsFor: 'private-resizing' stamp: 'janko 8/3/2008 16:59'!
resizeEnlarge
	"request resizing buffer to larger size at the next fill or flush"
	resize := #enlarge! !

!SwazooBuffer1 methodsFor: 'private-resizing' stamp: 'janko 8/3/2008 16:59'!
resizeNil
	"nil resizing command"
	resize := nil! !

!SwazooBuffer1 methodsFor: 'private-resizing' stamp: 'janko 8/3/2008 16:59'!
resizeShrink
	"request shrinking buffer to default size at the next fill or flush"
	resize := #shrink! !

!SwazooBuffer1 methodsFor: 'initialize-release' stamp: 'janko 8/3/2008 16:56'!
setRead
	type := #read! !

!SwazooBuffer1 methodsFor: 'initialize-release' stamp: 'janko 8/3/2008 16:56'!
setWrite
	type := #write! !

!SwazooBuffer1 methodsFor: 'private-resizing' stamp: 'janko 8/3/2008 16:59'!
shouldEnlarge
	"should be resized buffer to larger size?"
	^resize = #enlarge! !

!SwazooBuffer1 methodsFor: 'private-resizing' stamp: 'janko 8/3/2008 16:58'!
shouldResize
	^resize notNil! !

!SwazooBuffer1 methodsFor: 'private-resizing' stamp: 'janko 8/3/2008 16:58'!
shouldShrink
	"should be resized buffer to default size?"
	^resize = #shrink! !

!SwazooBuffer1 methodsFor: 'mime boundary' stamp: 'janko 7/26/2008 18:17'!
signsOfBoundary: aBoundaryBytes
	"detect as fast as possible if any if not all MIME part boundary is present in buffer contents"
	"return number of bundary bytes detected, 0 = no boundary"
	| first index |
	first := aBoundaryBytes first.
	"fast test"
	((self position+1 to: readLimit) contains: [:inx | (collection at: inx) = first]) ifFalse: [^0].
	"full or partial boundary on the edge of buffer test"
	index := self indexOfBoundary: aBoundaryBytes. "index of full, or partial boundary at the edge"
	index = 0 ifTrue: [^0]. "no boundary found"
	readLimit-index >= aBoundaryBytes size ifTrue: [^aBoundaryBytes size]. "full boundary detected"
	^readLimit-index+1  "partial boundary at the end of buffer"! !

!SwazooBuffer1 methodsFor: 'accessing' stamp: 'janko 7/26/2008 18:21'!
size
	^position - self class preambleSize! !

!SwazooBuffer1 methodsFor: 'mime boundary' stamp: 'janko 7/26/2008 18:17'!
startsWith: aPartialBoundaryBytes
	"is remaining part of MIME part boundary at the start of buffer?"
	"VW specific!! "
	1 to: aPartialBoundaryBytes size do: [:inx |
		(collection at: position + inx) = (aPartialBoundaryBytes at: inx) ifFalse: [^false] ].
	^true! !

!SwazooBuffer1 methodsFor: 'initialize-release' stamp: 'janko 7/26/2008 18:12'!
writeClear
	"reset as you'd make another one, just don't replace content array"
	self reset.
	readLimit := 0.
	self initPreamble.! !

OBCommand subclass: #WACmdAddAdaptor1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdAddAdaptor1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdAddAdaptor1 methodsFor: 'accessing' stamp: 'ewe 11/13/2012 11:36'!
adaptors
	^ (WAServerAdaptor allSubclasses reject: [ :each | each isAbstract ])
		asSortedCollection: [ :a :b | a name < b name ]! !

!WACmdAddAdaptor1 methodsFor: 'execution' stamp: 'ewe 11/13/2012 11:36'!
execute
	| class port adaptor |
	class := OBChoiceRequest 
		prompt: 'Chose adaptor type'
		labels: (self adaptors collect: [ :each | each name ])
		values: self adaptors.
	class isNil ifTrue: [ ^ self ].
	port := OBTextRequest 
		prompt: 'Enter port number'
		template: class basicNew defaultPort greaseString.
	(port isNil or: [ port isEmpty or: [ port isAllDigits not ] ]) ifTrue: [ ^ self ].
	adaptor := class port: port greaseInteger.
	requestor browser announce: (OBNodeCreated node: adaptor asNode)! !

!WACmdAddAdaptor1 methodsFor: 'accessing' stamp: 'lr 8/14/2010 09:21'!
group
	^ #changing! !

!WACmdAddAdaptor1 methodsFor: 'testing' stamp: 'lr 2/16/2009 20:43'!
isActive
	^ (requestor isSelected: target) not! !

!WACmdAddAdaptor1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdAddAdaptor1 methodsFor: 'accessing' stamp: 'lr 8/14/2010 09:21'!
label
	^ 'Add adaptor...'! !

OBCommand subclass: #WACmdAddHandler1
	instanceVariableNames: 'type __ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdAddHandler1 class methodsFor: 'accessing' stamp: 'jf 9/23/2009 23:41'!
instances
	^ WARequestHandler concreteSubclasses collect: [ :each | self new setType: each ]! !

!WACmdAddHandler1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdAddHandler1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/12/2012 14:18'!
ctxReadtype self isCtxGlobal
				 ifTrue: [ self synchronizeIfNecessary: 3 ]. ^  type! !

!WACmdAddHandler1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/12/2012 14:18'!
ctxWritetype: v2 self isCtxGlobal
				 ifTrue: [ self synchronizeIfNecessary: 3 . self markOtherAsDirty: 3 ]. ^ type := v2 secure  ! !

!WACmdAddHandler1 methodsFor: 'execution' stamp: 'jf 1/30/2009 17:36'!
execute
	| name handler |
	name := OBTextRequest prompt: 'Entry point name:'.
	(name isNil or: [ name isEmpty ]) ifTrue: [ ^ self ].
	handler := WAAdmin register: type at: name in: target handler.
	handler isApplication ifTrue: [ WAAdmin configureNewApplication: handler ].
	requestor browser announce: (OBNodeCreated node: handler asNode)! !

!WACmdAddHandler1 methodsFor: 'accessing' stamp: 'lr 1/23/2009 08:22'!
group
	^ #adding! !

!WACmdAddHandler1 methodsFor: 'testing' stamp: 'lr 1/20/2009 19:08'!
isActive
	^ (requestor isSelected: target) and: [ target isHandler and: [ target canHaveChildren ] ]! !

!WACmdAddHandler1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdAddHandler1 methodsFor: 'accessing' stamp: 'lr 1/20/2009 19:12'!
label
	^ 'Add ' , self type description! !

!WACmdAddHandler1 methodsFor: 'accessing' stamp: 'lr 1/20/2009 19:11'!
on: anObject for: aRequestor
	^ (super on: anObject for: aRequestor) setType: self type! !

!WACmdAddHandler1 methodsFor: 'initialization' stamp: 'lr 1/20/2009 19:11'!
setType: aClass
	type := aClass! !

!WACmdAddHandler1 methodsFor: 'accessing' stamp: 'lr 1/20/2009 19:11'!
type
	^ type! !

OBCommand subclass: #WACmdBrowseRequestHandler1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdBrowseRequestHandler1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdBrowseRequestHandler1 methodsFor: 'execution' stamp: 'lr 3/5/2009 21:55'!
execute
	(WAHandlerBrowser metaNode: WAHandlerBrowser adaptorMetaNode node: target copy) open! !

!WACmdBrowseRequestHandler1 methodsFor: 'accessing' stamp: 'lr 8/14/2010 09:20'!
group
	^ #browsing! !

!WACmdBrowseRequestHandler1 methodsFor: 'testing' stamp: 'jf 1/7/2009 21:19'!
isActive
	^ requestor isSelected: target! !

!WACmdBrowseRequestHandler1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdBrowseRequestHandler1 methodsFor: 'accessing' stamp: 'lr 1/20/2009 18:59'!
keystroke
	^ $b! !

!WACmdBrowseRequestHandler1 methodsFor: 'accessing' stamp: 'lr 1/20/2009 19:28'!
label
	^ 'Browse'! !

!WACmdBrowseRequestHandler1 methodsFor: 'testing' stamp: 'lr 8/14/2010 09:23'!
wantsButton
	^ true! !

OBCommand subclass: #WACmdClearConfigurationCaches1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdClearConfigurationCaches1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdClearConfigurationCaches1 methodsFor: 'execution' stamp: 'SK 9/4/2009 18:20'!
execute
	WAAdmin clearConfigurationCaches! !

!WACmdClearConfigurationCaches1 methodsFor: 'testing' stamp: 'SK 9/4/2009 18:21'!
group
	^ #manager! !

!WACmdClearConfigurationCaches1 methodsFor: 'testing' stamp: 'SK 9/4/2009 18:21'!
isActive
	^ requestor isSelected: target! !

!WACmdClearConfigurationCaches1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdClearConfigurationCaches1 methodsFor: 'accessing' stamp: 'SK 9/4/2009 18:20'!
label
	^ 'Clear configuration caches'! !

OBCommand subclass: #WACmdClearSessions1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdClearSessions1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdClearSessions1 methodsFor: 'execution' stamp: 'lr 1/23/2009 08:20'!
execute
	WAAdmin clearSessions! !

!WACmdClearSessions1 methodsFor: 'testing' stamp: 'MAD 1/20/2009 00:55'!
group
	^ #manager! !

!WACmdClearSessions1 methodsFor: 'testing' stamp: 'MAD 1/20/2009 00:51'!
isActive
	^ requestor isSelected: target! !

!WACmdClearSessions1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdClearSessions1 methodsFor: 'accessing' stamp: 'lr 1/23/2009 08:19'!
label
	^ 'Clear sessions'! !

OBCommand subclass: #WACmdEncodingForAdaptor1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdEncodingForAdaptor1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdEncodingForAdaptor1 methodsFor: 'accessing' stamp: 'jf 9/30/2009 00:27'!
codecs
	^ GRCodec allCodecs asSortedCollection: [ :a :b | a name < b name ]! !

!WACmdEncodingForAdaptor1 methodsFor: 'execution' stamp: 'jf 2/7/2009 20:27'!
execute
	| codec |
	codec := OBChoiceRequest
		prompt: 'Select encoding'
		labels: (self codecs 
			collect: [ :each | each name ]) 
		values: self codecs.
	codec isNil
		ifTrue: [ ^ self ].
	target adaptor codec: codec.
	requestor browser signalRefresh! !

!WACmdEncodingForAdaptor1 methodsFor: 'testing' stamp: 'MAD 1/10/2009 15:23'!
isActive
	^ requestor isSelected: target! !

!WACmdEncodingForAdaptor1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdEncodingForAdaptor1 methodsFor: 'accessing' stamp: 'lr 2/7/2009 10:20'!
label
	^ 'Encoding...'! !

OBCommand subclass: #WACmdInspectAdaptor1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdInspectAdaptor1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdInspectAdaptor1 methodsFor: 'execution' stamp: 'MAD 1/10/2009 17:57'!
execute
	target inspectAdaptor! !

!WACmdInspectAdaptor1 methodsFor: 'testing' stamp: 'MAD 1/10/2009 15:10'!
isActive
	^ requestor isSelected: target! !

!WACmdInspectAdaptor1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdInspectAdaptor1 methodsFor: 'accessing' stamp: 'jf 1/10/2009 23:50'!
keystroke
	^ $i! !

!WACmdInspectAdaptor1 methodsFor: 'accessing' stamp: 'lr 1/20/2009 19:27'!
label
	^ 'Inspect'! !

OBCommand subclass: #WACmdMode1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdMode1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdMode1 methodsFor: 'testing' stamp: 'lr 1/20/2009 19:28'!
cluster
	^ #Mode! !

!WACmdMode1 methodsFor: 'testing' stamp: 'lr 7/25/2011 18:37'!
isActive
	^ (requestor isSelected: target) and: [ target canChangeMode ]! !

!WACmdMode1 methodsFor: 'testing' stamp: 'lr 7/25/2011 18:37'!
isEnabled
	^ (requestor isSelected: target) and: [ target canChangeMode ]! !

!WACmdMode1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdMode1 methodsFor: 'testing' stamp: 'lr 1/20/2009 19:27'!
label
	^ 'Mode'! !

WACmdMode1 subclass: #WACmdModeDebug1
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdModeDebug1 methodsFor: 'execution' stamp: 'MAD 1/10/2009 18:06'!
execute
	target setDebugMode! !

!WACmdModeDebug1 methodsFor: 'testing' stamp: 'lr 1/20/2009 19:27'!
label
	^ 'Debug'! !

WACmdMode1 subclass: #WACmdModeDeployment1
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdModeDeployment1 methodsFor: 'execution' stamp: 'MAD 1/10/2009 18:06'!
execute
	target setDeploymentMode! !

!WACmdModeDeployment1 methodsFor: 'testing' stamp: 'lr 1/20/2009 19:27'!
label
	^ 'Deployment'! !

WACmdMode1 subclass: #WACmdModeVerbose1
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdModeVerbose1 methodsFor: 'execution' stamp: 'MAD 1/10/2009 18:06'!
execute
	target setVerboseMode! !

!WACmdModeVerbose1 methodsFor: 'testing' stamp: 'lr 1/20/2009 19:27'!
label
	^ 'Verbose'! !

OBCommand subclass: #WACmdPortForAdaptor1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdPortForAdaptor1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdPortForAdaptor1 methodsFor: 'execution' stamp: 'pmm 12/12/2010 11:19'!
execute
	| port |
	port := OBTextRequest 
		prompt: 'Enter port number'
		template: target adaptor port greaseString.
	(port isNil or: [ port isEmpty or: [ port isAllDigits not ] ]) ifTrue: [ ^ self ].
	target adaptor port: port greaseInteger.
	requestor browser signalRefresh! !

!WACmdPortForAdaptor1 methodsFor: 'testing' stamp: 'pmm 12/12/2010 11:13'!
isActive
	^ (requestor isSelected: target)
		and: [ target isStopped ]! !

!WACmdPortForAdaptor1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdPortForAdaptor1 methodsFor: 'accessing' stamp: 'pmm 12/12/2010 11:11'!
label
	^ 'Port...'! !

OBCommand subclass: #WACmdRemoveAdaptor1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdRemoveAdaptor1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdRemoveAdaptor1 methodsFor: 'execution' stamp: 'lr 1/23/2009 08:32'!
execute
	target remove.
	requestor browser announce: (OBNodeDeleted node: target)! !

!WACmdRemoveAdaptor1 methodsFor: 'accessing' stamp: 'lr 8/14/2010 09:22'!
group
	^ #changing! !

!WACmdRemoveAdaptor1 methodsFor: 'testing' stamp: 'jf 1/7/2009 21:26'!
isActive
	^ requestor isSelected: target! !

!WACmdRemoveAdaptor1 methodsFor: 'testing' stamp: 'jf 1/7/2009 21:25'!
isEnabled
	^ (requestor isSelected: target) and: [ target canRemove ]! !

!WACmdRemoveAdaptor1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdRemoveAdaptor1 methodsFor: 'accessing' stamp: 'jf 1/7/2009 21:28'!
keystroke
	^ $x! !

!WACmdRemoveAdaptor1 methodsFor: 'accessing' stamp: 'lr 8/14/2010 09:21'!
label
	^ 'Remove adaptor'! !

OBCommand subclass: #WACmdRemoveExpression1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdRemoveExpression1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdRemoveExpression1 methodsFor: 'execution' stamp: 'jf 1/12/2009 12:06'!
execute
	target removeExpression! !

!WACmdRemoveExpression1 methodsFor: 'testing' stamp: 'jf 1/12/2009 12:04'!
isActive
	^ (requestor isSelected: target) and: [ target isAttribute ]! !

!WACmdRemoveExpression1 methodsFor: 'testing' stamp: 'jf 1/12/2009 12:05'!
isEnabled
	^ target isOverride! !

!WACmdRemoveExpression1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdRemoveExpression1 methodsFor: 'accessing' stamp: 'jf 1/12/2009 12:04'!
label
	^ 'Clear value'! !

OBCommand subclass: #WACmdRemoveHandler1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdRemoveHandler1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdRemoveHandler1 methodsFor: 'execution' stamp: 'lr 1/20/2009 19:26'!
execute
	target handler parent unregister: target handler.
	requestor browser announce: (OBNodeDeleted node: target)! !

!WACmdRemoveHandler1 methodsFor: 'testing' stamp: 'lr 1/20/2009 19:26'!
isActive
	^ (requestor isSelected: target) and: [ target isHandler and: [ target handler isRoot not ] ]! !

!WACmdRemoveHandler1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdRemoveHandler1 methodsFor: 'accessing' stamp: 'lr 1/20/2009 19:21'!
keystroke
	^ $x! !

!WACmdRemoveHandler1 methodsFor: 'accessing' stamp: 'lr 1/20/2009 19:21'!
label
	^ 'Remove'! !

OBCommand subclass: #WACmdStartAdaptor1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdStartAdaptor1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdStartAdaptor1 methodsFor: 'execution' stamp: 'MAD 1/10/2009 17:08'!
execute
	self isEnabled ifFalse: [ ^ nil ].
	target start.
	requestor browser signalRefresh! !

!WACmdStartAdaptor1 methodsFor: 'testing' stamp: 'MAD 1/10/2009 16:47'!
isActive
	^ requestor isSelected: target! !

!WACmdStartAdaptor1 methodsFor: 'testing' stamp: 'lr 9/8/2009 19:44'!
isEnabled
	^ (requestor isSelected: target) and: [ target isServerAdaptor and: [ target canStart ] ]! !

!WACmdStartAdaptor1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdStartAdaptor1 methodsFor: 'accessing' stamp: 'jf 1/10/2009 23:51'!
keystroke
	^ $s! !

!WACmdStartAdaptor1 methodsFor: 'accessing' stamp: 'lr 1/20/2009 19:28'!
label
	^ 'Start'! !

!WACmdStartAdaptor1 methodsFor: 'testing' stamp: 'MAD 1/10/2009 16:47'!
wantsButton
	^ true! !

OBCommand subclass: #WACmdStopAdaptor1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdStopAdaptor1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdStopAdaptor1 methodsFor: 'execution' stamp: 'MAD 1/10/2009 17:07'!
execute
	self isEnabled ifFalse: [ ^ nil ].
	target stop.
	requestor browser signalRefresh! !

!WACmdStopAdaptor1 methodsFor: 'testing' stamp: 'MAD 1/10/2009 17:06'!
isActive
	^ requestor isSelected: target! !

!WACmdStopAdaptor1 methodsFor: 'testing' stamp: 'lr 9/8/2009 19:44'!
isEnabled
	^ (requestor isSelected: target) and: [ target isServerAdaptor and: [ target canStop ] ]! !

!WACmdStopAdaptor1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdStopAdaptor1 methodsFor: 'accessing' stamp: 'jf 1/10/2009 23:51'!
keystroke
	^ $s! !

!WACmdStopAdaptor1 methodsFor: 'accessing' stamp: 'lr 1/20/2009 19:28'!
label
	^ 'Stop'! !

!WACmdStopAdaptor1 methodsFor: 'testing' stamp: 'MAD 1/10/2009 16:47'!
wantsButton
	^ true! !

OBCommand subclass: #WACmdToggleStreamUploads1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdToggleStreamUploads1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdToggleStreamUploads1 methodsFor: 'user interface' stamp: 'lr 7/25/2011 19:53'!
addItemToMenu: aMenu
	"Hack. Must nuke the default blankIcon used by OB."

	super addItemToMenu: aMenu.
	self isActive
		ifFalse: [ ^ self ].
	aMenu lastItem icon: nil! !

!WACmdToggleStreamUploads1 methodsFor: 'execution' stamp: 'pmm 12/12/2010 18:16'!
execute
	target adaptor streamUploads: target adaptor streamUploads not.
	requestor browser signalRefresh! !

!WACmdToggleStreamUploads1 methodsFor: 'testing' stamp: 'pmm 12/12/2010 18:17'!
isActive
	^ (requestor isSelected: target)
		and: [ target isStopped
		and: [ target canChangeStreamUploads ] ]! !

!WACmdToggleStreamUploads1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdToggleStreamUploads1 methodsFor: 'accessing' stamp: 'pmm 12/12/2010 18:17'!
label
	^ target isStreamingUploads
		ifTrue: [ '<on>Stream uploads' ]
		ifFalse: [ '<off>Stream uploads' ]! !

OBCommand subclass: #WACmdUseNewDispatcher1
	instanceVariableNames: '__ctxInfo__'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ExcludedWeb1'!

!WACmdUseNewDispatcher1 class methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdUseNewDispatcher1 methodsFor: 'execution' stamp: 'MAD 2/21/2009 18:56'!
execute
	| dispatcher |
	(OBConfirmationRequest 
		prompt: 'This will replace all applications on this server instance' 
		confirm: 'Proceed')
			ifFalse: [ ^ nil ].
	dispatcher := WADispatcher new.
	target adaptor requestHandler: dispatcher.
	requestor browser announce: (OBNodeCreated node: dispatcher asNode)! !

!WACmdUseNewDispatcher1 methodsFor: 'testing' stamp: 'MAD 2/21/2009 18:17'!
isActive
	^ requestor isSelected: target! !

!WACmdUseNewDispatcher1 methodsFor: 'as yet unclassified' stamp: 'ewe 11/16/2012 12:16'!
isPrimitive ^ true! !

!WACmdUseNewDispatcher1 methodsFor: 'accessing' stamp: 'MAD 2/21/2009 18:54'!
label
	^ 'Use new dispatcher'! !
